@echo off
setlocal

REM ********************************************
REM QPR Installation folders (Edit if necessary):
REM ********************************************

set QPR_PDATA=C:\ProgramData\QPR Software\QPR 2017\2017.1\
set QPR_INETPUB=C:\inetpub\wwwroot\qpr2017-1\




REM ********************************************
REM Don't touch anything after this
REM ********************************************

echo ******************************************************
echo * World Calendars for QPR Portal installation script *
echo *        Copyright (C) 2017 QPR Software Plc         *
echo ******************************************************
echo.

IF NOT EXIST "%QPR_PDATA%" GOTO PDATA_MISSING			:: Make sure the folder exists...
IF NOT EXIST "%QPR_PDATA%\Servers\" GOTO WRONG_PDATA	:: ...and that it is the correct folder
IF NOT EXIST "%QPR_INETPUB%" GOTO INETPUB_MISSING
IF NOT EXIST "%QPR_INETPUB%\qprsoftware\" GOTO WRONG_INETPUB

echo Target folder (ProgramData): %QPR_PDATA%
echo Target folder (wwwroot):     %QPR_INETPUB%
echo.
echo Make sure these folders are correct before proceeding (change them inside install.bat if necessary).
echo.
SET /P AREYOUSURE=Do you want to continue the installation (Y/[N])? 
IF /I "%AREYOUSURE%" NEQ "Y" GOTO END

echo Copying files...

pushd %~dp0

xcopy /Q install_data\worldcalendarjs.tpl "%QPR_PDATA%\Servers\Templates\WAS\Common\"
xcopy /Q install_data\worldcalendarjs.tpl "%QPR_PDATA%\Servers\Templates\WAS\Common\StaticFields\"

xcopy /Q install_data\jquery.calendars\* "%QPR_INETPUB%\qprsoftware\Common\scripts\calendar\jquery.calendars\"
xcopy /Q install_data\icon_world_calendar.gif "%QPR_INETPUB%\qprsoftware\portal\images\"

REM Note: Patch.exe provided by GnuWin32 butchers file permissions (ACL), but the one included with Git for Windows does not -> use that

echo Applying patches...
install_data\patch.exe -d "%QPR_PDATA%\Servers\Templates\WAS" -p0 < install_data\WAS.patch
install_data\patch.exe -d "%QPR_INETPUB%\qprsoftware" -p0 < install_data\qprsoftware.patch

popd

echo.
echo Patching complete!
echo.
echo If you see any "Hunk FAILED" messages above, it means this accelerator is not compatible with your QPR version,
echo or there are too many existing customizations preventing the installation.
echo.
echo You should now configure the accelerator by modifying the settings inside:
echo.
echo %QPR_INETPUB%\qprsoftware\portal\scripts\utils.js
echo.
echo Please refer to the included Word document on how to do this.

goto end

:PDATA_MISSING
ECHO Error: Target folder doesn't exist: %QPR_PDATA%
echo.
ECHO Please edit the variable QPR_PDATA inside install.bat to point to your QPR installation's data folder located
echo under %PROGRAMDATA% (usually C:\ProgramData\QPR Software\QPR 201x\201x.1\)
goto end

:WRONG_PDATA
ECHO Error: Target folder doesn't exist: %QPR_PDATA%\Servers\
echo.
echo Variable QPR_DATA specified inside install.bat points to a folder that does not contain a subfolder called "Servers".
ECHO Please make sure it points to the correct QPR data folder (usually C:\ProgramData\QPR Software\QPR 201x\201x.1\)
goto end

:INETPUB_MISSING
ECHO Error: Target folder doesn't exist: %QPR_INETPUB%
echo.
ECHO Please edit the variable QPR_INETPUB inside install.bat to point to the correct WWW folder (usually C:\inetpub\wwwroot\qpr201x-1\)
goto end

:WRONG_INETPUB
ECHO Error: Target folder doesn't exist: %QPR_INETPUB%\qprsoftware\
echo.
echo Variable QPR_INETPUB specified inside install.bat points to a folder that does not contain a subfolder called "qprsoftware".
ECHO Please make sure it points to the correct WWW folder (usually C:\inetpub\wwwroot\qpr201x-1\)
goto end

:END
endlocal
echo.
pause